var AMWAY = AMWAY || {};
AMWAY.IncomeSimulator = AMWAY.IncomeSimulator || {};

AMWAY.IncomeSimulator.Country = (function(){
	// Supported income simulator countries
    var _countries = {
		'us':'United States of America',
		'ar':'Argentina',
		'au':'Australia',
		'at':'Austria',
		'be':'Belgium',
		'bw':'Botswana',
		'br':'Brazil',
		'bn':'Brunei',
		'ca':'Canada',
		'cl':'Chile',
		'cn':'China',
		'co':'Colombia',
		'cr':'Costa Rica',
		'hr':'Croatia',
		'cz':'Czech Republic',
		'dk':'Denmark',
		'do':'Dominican Republic',
		'sv':'El Salvador',
		'fi':'Finland',
		'fr':'France',
		'de':'Germany',
		'gr':'Greece',
		'gt':'Guatemala',
		'hn':'Honduras',
		'hk':'Hong Kong',
		'hu':'Hungary',
		'in':'India',
		'id':'Indonesia',
		'ie':'Ireland',
		'it':'Italy',
		'jp':'Japan',
		'kp':"Korea, Democratic People's Republic of",
		'my':'Malaysia',
		'mx':'Mexico',
		'na':'Namibia',
		'nl':'Netherlands',
		'nz':'New Zealand',
		'no':'Norway',
		'pa':'Panama',
		'ph':'Philippines',
		'pl':'Poland',
		'pt':'Portugal',
		'ro':'Romania',
		'ru':'Russian Federation',
		'sg':'Singapore',
		'sk':'Slovakia',
		'si':'Slovenia',
		'za':'South Africa',
		'es':'Spain',
		'se':'Sweden',
		'ch':'Switzerland',
		'tw':'Taiwan',
		'th':'Thailand',
		'tr':'Turkey',
		'ua':'Ukraine',
		'gb':'United Kingdom',
		'uy':'Uruguay',
		've':'Venezuela',
		'vn':'Viet Nam'
	};
	
	// Stores loaded country settings
	var _settings = {};
	
	/**
	 * Set the country specific currency formatting
	 * @param {Object} format
	 */
	var _setCurrencyFormat = function(format)
	{
		AMWAY.IncomeSimulator.Main.settings.currencySymbol = format.currencySymbol;
		AMWAY.IncomeSimulator.Main.settings.decimalPlaces = format.decimalPlaces;
		AMWAY.IncomeSimulator.Main.settings.decimalSymbol = format.decimalSymbol;
		AMWAY.IncomeSimulator.Main.settings.thousandsSymbol = format.thousandsSeparator;
	};
	
	var _initUI = function()
	{
		$('select#select-country').change(function(){
			AMWAY.IncomeSimulator.Main.loadCountry($(this).val());
		});
		
		var n = AMWAY.IncomeSimulator.Main.settings.availableCountries.length;
		
		for(var i = 0; i < n; i++)
		{
			
			var countryCode = AMWAY.IncomeSimulator.Main.settings.availableCountries[i];
			var option = '<option value="'+countryCode+'">'+ _countries[countryCode]+'</option>';
			$('select#select-country').append(option);
		}
		
		
			//var countryCode = AMWAY.IncomeSimulator.Main.settings.availableCountries[i];
			//console.log(countryCode);
			//
			//
		
		// make country input fancy!
		$('select#select-country').selectBox();
		//$('select#select-language').selectBox();
	};
	
	/**
	 * Update the simulator model with country specific options
	 * @param {Object} options
	 */
	var _setIncomeSimulatorModelOptions = function(options)
	{
		AMWAY.IncomeSimulator.setModelValue('myGoals', 'maxMonthlyIncome', options.myGoals.maxMonthlyIncome);
		AMWAY.IncomeSimulator.setModelValue('myGoals', 'averageSalesPerClient', options.myGoals.averageSalesPerClient);
		AMWAY.IncomeSimulator.setModelValue('retailing', 'maxPersonalOrders', options.retailing.maxPersonalOrders);
		AMWAY.IncomeSimulator.setModelValue('retailing', 'maxNumberOfClients', options.retailing.maxNumberOfClients);
		AMWAY.IncomeSimulator.setModelValue('retailing', 'maxSalesPerClient', options.retailing.maxSalesPerClient);
		AMWAY.IncomeSimulator.setModelValue('businessBuilding', 'maxPersonalOrders', options.businessBuilding.maxPersonalOrders);
		AMWAY.IncomeSimulator.setModelValue('businessBuilding', 'maxNumberOfClients', options.businessBuilding.maxNumberOfClients);
		AMWAY.IncomeSimulator.setModelValue('businessBuilding', 'maxSalesPerClient', options.businessBuilding.maxSalesPerClient);
		AMWAY.IncomeSimulator.setModelValue('businessBuilding', 'maxRetailPerLeg', options.businessBuilding.maxRetailPerLeg);
		AMWAY.IncomeSimulator.setModelValue('businessBuilding','ratios', options.businessBuilding.ratios);
		
		AMWAY.IncomeSimulator.setModelValue('bonuses', 'perfSchedules', options.perfSchedules);
		AMWAY.IncomeSimulator.setModelValue('bonuses', 'ruby', options.ruby);
		AMWAY.IncomeSimulator.setModelValue('bonuses', 'leadership', options.leadership);
	};
	
	var _languageSelectChange = function(){
		AMWAY.IncomeSimulator.Main.loadLanguage($(this).val());		
	};
	
	/**
	 * Build the language selection dropdown based on available
	 * languages.
	 * @param {Array} languages
	 */
	var _buildLanguageSelectionDropdown = function(languages)
	{
		// destroy fancy dropdown formatting
		$('select#select-language').selectBox('destroy');
		// clear select element
		$('select#select-language').html('');
		
		// add language options to select element
		for(var i=0; i < languages.length; i++)
		{
			var code = languages[i];
			var option = '<option value="'+ code +'">'+ AMWAY.IncomeSimulator.Translation.getLanguageName(code)+'</option>';
			
			$('select#select-language').append(option);
		}
		
		// bind change function to repopulated 
		$('select#select-language').unbind('change', _languageSelectChange);
		$('select#select-language').bind('change', _languageSelectChange);
		
		$('select#select-language').selectBox('create');
		
		// when the select box is destroyed and then created,
		// the width has to be re-applied. 
		$('.selectBox').css('width', '210px');
	};
	
	/**
	 * Initialize country specific settings
	 * @param {Object} settings
	 */
	var _initializeCountry = function(settings)
	{
		// build language selection dropdown
		_buildLanguageSelectionDropdown(settings.languages);
		// set currency format
		_setCurrencyFormat(settings.currencyFormat);
		// set default language
		AMWAY.IncomeSimulator.Main.settings.languageCode = settings.languages[0];
		//_setIncomeSimulatorModelOptions(settings.simulatorOptions);
	};
	
	/**
	 * Called when country settings are loaded. Initialize country specific
	 * settings when data is loaded.
	 * @param {Object} data
	 */
	var _onLoad = function(data)
	{
		_settings = data;
		// convert json string to object if running locally
		if(AMWAY.IncomeSimulator.Main.settings.local)
		{
			_settings = $.parseJSON(_settings);
		}
		
		_initializeCountry(_settings);
	};
	
	/**
	 * Public methods and properties
	 */
	return {
		countries: _countries,
		settings: _settings,
		onLoad: _onLoad,
		initUI: _initUI
	};
}());
