var AMWAY = AMWAY || {};
AMWAY.IncomeSimulator = AMWAY.IncomeSimulator || {};

AMWAY.IncomeSimulator.Profiles = (function(){
	var _currentProfile;
	var _profiles = {};
	var _currentProfileContent;
	
	var _initUI = function()
	{
		
	};
	
	/**
	 * Clears all values from profile content html
	 */
	var _clearProfileContent = function()
	{
		$('.profile .name .value').text('');
		$('.profile .age .value').text('');
		$('.profile .relationship .value').text('');
		$('.profile .status .value').text('');
		$('.profile .retailing .value').text('');
		$('.profile .description-container').text('');
		$('.profile .clientCount .value').text('').parent().hide();
		$('.profile .downlineCount .value').text('').parent().hide();
		$('.profile .illustration .image').html('');
	};
	
	/**
	 * Sets profile content html text
	 * @param {Object} index
	 */
	var _setProfileContent = function(index)
	{
		var content = _currentProfileContent[index];

		$('.profile .name .value').text(content.name);
		$('.profile .age .value').text(content.age);
		$('.profile .relationship .value').text(content.relationship);
		$('.profile .status .value').text(content.amwayStatus);
		$('.profile .retailing .value').text(content.retailing);
		$('.profile .description-container').text(content.description);
		
		if(content.clientCount)
		{
			$('.profile .clientCount .value').text(content.clientCount).parent().show();
		}
		
		if(content.downlineCount)
		{
			$('.profile .downlineCount .value').text(content.downlineCount).parent().show();
		}
		
		if(content.illustration && content.illustration.length)
		{
			var n = content.illustration.length;
			
			for(var i = 0; i < n; i++)
			{
				$('.profile .illustration .image').append('<img src="'+ content.illustration[i] +'" alt="" />');
			}
			
		}
		
		if(!content.illustration && !content.downlineCount && !content.clientCount)
		{
			$('.profile .illustration').hide();
		}
		else{
			$('.profile .illustration').show();
		}
	};
	
	/**
	 * Adds image tags to the profile button element
	 * @param {Array} images
	 */
	var _displayProfileButtonImages = function(images)
	{
		var n = images.length;
		var html = "";
		var css = "";
		
		var maskSize = "large";
		var backgroundPosition = "15px 15px";
		var imgWidth = 170;
		var imgHeight = 170;
		var imgMargin = 20;
		
		switch(n)
		{
			case 5:
				imgWidth = 136;
				imgHeight = 136;
				imgMargin = 10;
				maskSize = "medium";
				backgroundPosition = "11px 11px";
				break;
			case 6:
				imgWidth = 120;
				imgHeight = 120;
				imgMargin = 0;
				maskSize = "small"
				backgroundPosition = "11px 11px";
				break;
		}
		
		var profilesWidth = (n * imgWidth) + ((n - 1) * imgMargin);
		$("#profile-buttons").css("width", profilesWidth +"px");
		
		$("#profile-buttons").html("");
		
		for(var i=0; i < n; i++)
		{
			
			html = "<div id=\"profile-"+ (i + 1) +"\" class=\"profile-button "+maskSize+"\"><div class=\"profile-button-mask\"></div></div>";
			$("#profile-buttons").append(html);
			
			
			css = "#FFFFFF url("+images[i]+") "+backgroundPosition +" no-repeat";
			$('#profile-'+(i + 1)).css('background', css).show();
		}
		
		$('.profile-button').css('margin-left', imgMargin +"px");
		$('.profile-button:first-child').css('margin-left', '0px')
		
		/*
		for(var i=0; i < images.length; i++)
		{
			var css = "url("+images[i]+") 15px 15px no-repeat";
			$('#profile-'+(i + 1)).css('background', css);
		}
		*/
		
	};
	
	var _setProfileImageListeners = function()
	{
		$('.profile-button').click(function(e){
			var $this = $(this);
			
			if(_currentProfile != $this.index())
			{
				_currentProfile = $this.index();
				
				$('.profile-button').each(function(){
					if($this.index() != $(this).index())
					{
						$(this).fadeTo(300, .25);
					}
					else {
						$(this).fadeTo(300, 1);
					}
				});
				
				$('#profile-content').slideUp(300, function(){
					_clearProfileContent();
					_setProfileContent($this.index());
					
					$('#profile-content').slideDown(300);
				});
				return;
			}
			
			// reset current profile index
			_currentProfile = null;
			// hide content
			$('#profile-content').slideUp(300);
			
			// fade all buttons in
			$('.profile-button').each(function(){
				$(this).fadeTo(300, 1);
			});
		});
	}
	
	var _initializeProfiles = function(profiles, languageCode)
	{
		_reset();
		
		_displayProfileButtonImages(profiles.images);
		_setProfileImageListeners();
		_currentProfileContent = profiles.content[languageCode];
	};
	
	var _initializeDisclaimer = function(disclaimers)
	{
		$('.page#owner-profiles #disclaimer ul').html('');
		
		for(var i in disclaimers)
		{
			var disclaimer = "<li>"+disclaimers[i]+"</li>";
			$('.page#owner-profiles #disclaimer ul').append(disclaimer);
		}
	};
	
	var _reset = function()
	{
		$('#profile-content').hide();
		$('.profile-button').each(function(){
			$(this).fadeTo(0, 1);
		});
		
		_currentProfile = null;
	};
	
	var _onLoadStart = function()
	{
		$("#profile-buttons").html("");
	}
	
	var _onLoad = function(data)
	{
		_profiles = data;
		
		if(AMWAY.IncomeSimulator.Main.settings.local)
		{
			_profiles = $.parseJSON(_profiles);
		}
		
		var langCode = AMWAY.IncomeSimulator.Main.settings.languageCode;
		
		_initializeProfiles(_profiles, langCode);
		_initializeDisclaimer(_profiles.disclaimer[langCode]);
	};
	
	return {
		onLoad: _onLoad,
		onLoadStart: _onLoadStart,
		initUI: _initUI,
		reset: _reset
	};
}());