var AMWAY = AMWAY || {};
AMWAY.IncomeSimulator = AMWAY.IncomeSimulator || {};

AMWAY.IncomeSimulator.Simulator = (function(){

	var _settings;
	var _myGoalsBarMaxWidth = 583;
	var _currentTab;
	
	var _model = {
		myGoals: {
			desiredIncome: 0,
			numberOfClients: 0,
			salesPerClient: 0,
			totalRetailSales: 0,
			totalRetailProfit: 0,
			retailDiscountPct: 0,
			retailMargin: 0,
			monthlyIncome: 0,
			annualIncome: 0,
			category: {},
			averageSalesPerClient: 0,
			maxMonthlyIncome: 0,
			productCategoryIndex: 0
		},
		retailing:
		{
			personalOrders: 0,
			numberOfClients: 0,
			salesPerClient: 0,
			totalRetailSales: 0,
			totalRetailProfit: 0,
			retailDiscountPct: 0,
			retailMargin: 0,
			totalPV: 0,
			totalBV: 0,
			perfBnsPct: 0,
			perfBnsAmt: 0,
			monthlyIncome: 0,
			annualIncome: 0,
			category: {},
			maxPersonalOrders: 0,
			maxNumberOfClients: 0,
			maxSalesPerClient: 0,
			maxMonthlyIncome: 0
		},
		businessBuilding:
		{
			totalRetailSales: 0,
			totalRetailProfit: 0,
			retailMargin: 0,
			perfBnsPct: 0,
			personalPerfBonus: 0,
			passupPerfBonus: 0,
			leadershipBonus: 0,
			rubyBonus: 0,
			monthlyIncome: 0,
			annualIncome: 0,
			personalOrders: 0,
			numberOfClients: 0,
			salesPerClient: 0,
			legRetail: [0, 0, 0],
			leg: [],
			maxRetailPerLeg: 0,
			maxPersonalOrders: 0,
			maxNumberOfClients: 0,
			maxSalesPerClient: 0,
			maxMonthlyIncome: 0,
			ratios: {}
		},
		bonuses:
		{
			/*
			 * perfSchedules[n][0]: PV
			 * perfSchedules[n][1]: Percent
			 */
			perfSchedules: [],
			/*
			 * ruby[0]: PV
			 * ruby[1]: Percent
			 */
			ruby: [],
			/*
			 * leadership[0]: Leadership Bonus percent
			 * leadership[1]: Leadership Bonus Award amount
			 * leadership[2]: Leadership Bonus Award percent
			 * leadership[3]: PV max Performance Schedule
			 * leadership[4]: PV side volume
			 */
			leadership: []
		}
	};
	
	var _formatMoney = function(n)
	{
		var p = AMWAY.IncomeSimulator.Main.settings.decimalPlaces;
		var c = AMWAY.IncomeSimulator.Main.settings.currencySymbol;
		var d = AMWAY.IncomeSimulator.Main.settings.decimalSymbol;
		var t = AMWAY.IncomeSimulator.Main.settings.thousandsSymbol;
		
		// decimal places
		p = isNaN(p = Math.abs(p)) ? 2 : p;
		// decimal symbol
		d = d == undefined ? "," : d;
		// thousands symbol
		t = t == undefined ? "." : t;

		// signed
		var s = n < 0 ? "-" : "";
		// integer
		var i = parseInt(n = Math.abs(+n || 0).toFixed(p)) + "";
		var j = (j = i.length) > 3 ? j % 3 : 0;

		return s + (j ? i.substr(0, j) + t : "") + i.substr(j).replace(/(\d{3})(?=\d)/g, "$1" + t) + (p ? d + Math.abs(n - i).toFixed(p).slice(2) : "") + c;

	};
	
	var _updateMyGoalsView = function()
	 {
	 	var desiredIncome = _formatMoney(_model.myGoals.desiredIncome);
		var totalRetailSales = _formatMoney(_model.myGoals.totalRetailSales);
		var totalRetailProfit = _formatMoney(_model.myGoals.totalRetailProfit);
		var annualIncome = _formatMoney(_model.myGoals.annualIncome);
	 	var salesPerClient = _formatMoney(_model.myGoals.salesPerClient);

		$('#my-goals-client-number .client-number.value').text(_model.myGoals.numberOfClients);
		$('#my-goals-client-number .sales-per-client.value').text(salesPerClient);
		$('#my-goals-monthly-earnings .value').text(desiredIncome);
		$('#my-goals-income-bar .bubble-text .value').text(totalRetailProfit);
		$('#my-goals-content-total-retail-sales .value').text(totalRetailSales);
		$('#my-goals-content-total-retail-profit .value').text(totalRetailProfit);
		$('#my-goals-content-summary-monthly-income .value').text(totalRetailProfit);
		$('#my-goals-content-summary-yearly-income .value').text(annualIncome);
		
		$('#my-goals-product-category .product-list').html('');
		$('#my-goals-retail-margin .value').text(_model.myGoals.retailMargin +"%");
		
		for(var i = 0; i < _model.myGoals.category.products.length; i++)
		{
			var product = _model.myGoals.category.products[i];
			
			var productElement = '<div class="labeled-value clear"><span class="label">'+ product.name+'</span><span class="value">'+ Math.ceil(product.myGoalsTotalProductCount) +'</span></div>';
			$('#my-goals-product-category .product-list').append(productElement);
		}
		
		var earningsPercent = _model.myGoals.desiredIncome / _model.myGoals.maxMonthlyIncome;
		$('#my-goals-income-bar .bar .display .retail-profit').width(earningsPercent * _myGoalsBarMaxWidth);
	};
	
	var _updateRetailingView = function()
	{
		
		var personalOrders = _formatMoney(_model.retailing.personalOrders);
		var salesPerClient = _formatMoney(_model.retailing.salesPerClient);
		var totalRetailSales = _formatMoney(_model.retailing.totalRetailSales);
		var totalRetailProfit = _formatMoney(_model.retailing.totalRetailProfit);
		var perfBnsAmt = _formatMoney(_model.retailing.perfBnsAmt);
		var monthlyIncome = _formatMoney(_model.retailing.monthlyIncome);
		var annualIncome = _formatMoney(_model.retailing.annualIncome);
		
		$('.retailing-personal-orders-slider .value').text(personalOrders);
		$('.retailing-number-of-clients-slider .value').text(_model.retailing.numberOfClients);
		$('.retailing-sales-per-client-slider .value').text(salesPerClient);
		
		$('#retailing-content-total-retail-sales .value').text(totalRetailSales);
		$('#retailing-content-total-retail-profit .value').text(totalRetailProfit);
		
		$('#retailing-income-bar .bubble-text .value').text(monthlyIncome);
		$('#retailing-content-personal-performance-bonus .percent').text('('+ _model.retailing.perfBnsPct * 100 +'%)');
		$('#retailing-content-personal-performance-bonus .value').text(perfBnsAmt);
		$('#retailing-content-summary-monthly-income .value').text(monthlyIncome);
		$('#retailing-content-summary-annual-income .value').text(annualIncome);
		
		$('#retailing-retail-margin .value').text(_model.retailing.retailMargin + "%");
		
		$('#retailing-product-category .product-list').html('');
		
		for(var i = 0; i < _model.retailing.category.products.length; i++)
		{
			var product = _model.retailing.category.products[i];
			
			var productElement = '<div class="labeled-value clear"><span class="label">'+ product.name+'</span><span class="value">'+ Math.round(product.retailingTotalProductCount) +'</span></div>';
			$('#retailing-product-category .product-list').append(productElement);
		}
		
		var totalMonthlyIncomeWidth = (_model.retailing.monthlyIncome / _model.retailing.maxMonthlyIncome) * _myGoalsBarMaxWidth;
		
		var retailProfitWidth = (_model.retailing.totalRetailProfit / _model.retailing.monthlyIncome) * totalMonthlyIncomeWidth;
		var personalPerformanceWidth = (_model.retailing.perfBnsAmt / _model.retailing.monthlyIncome) * totalMonthlyIncomeWidth;
		retailProfitWidth = isNaN(retailProfitWidth) ? 0 : retailProfitWidth;
		personalPerformanceWidth = isNaN(personalPerformanceWidth) ? 0: personalPerformanceWidth;
		$('#retailing-income-bar .bar .display .retail-profit').width(retailProfitWidth);
		$('#retailing-income-bar .bar .display .personal-performance').width(personalPerformanceWidth);
	};
	
	var _updateBusinessBuildingView = function(){
		
		var personalOrders = _formatMoney(_model.businessBuilding.personalOrders);
		var salesPerClient = _formatMoney(_model.businessBuilding.salesPerClient);
		var legOneRetail = _formatMoney(_model.businessBuilding.legRetail[0]);
		var legTwoRetail = _formatMoney(_model.businessBuilding.legRetail[1]);
		var legThreeRetail = _formatMoney(_model.businessBuilding.legRetail[2]);
		
		var retailSales = _formatMoney(_model.businessBuilding.totalRetailSales);
		var retailProfit = _formatMoney(_model.businessBuilding.totalRetailProfit);
		var monthlyIncome = _formatMoney(_model.businessBuilding.monthlyIncome);
		var annualIncome = _formatMoney(_model.businessBuilding.annualIncome);
		
		var personalPerformanceBonus = _formatMoney(_model.businessBuilding.personalPerfBonus);
		var passupPerformanceBonus = _formatMoney(_model.businessBuilding.passupPerfBonus);
		var rubyBonus = _formatMoney(_model.businessBuilding.rubyBonus);
		var leadershipBonus = _formatMoney(_model.businessBuilding.leadershipBonus);
		
		$('.business-building-personal-orders-slider .value').text(personalOrders);
		$('.business-building-number-of-clients-slider .value').text(_model.businessBuilding.numberOfClients);
		$('.business-building-sales-per-client-slider .value').text(salesPerClient);
		
		$('.leg-1-slider .value').text(legOneRetail);
		$('.leg-2-slider .value').text(legTwoRetail);
		$('.leg-3-slider .value').text(legThreeRetail);
		
		var legOnePercent = _model.businessBuilding.leg[0].perfPct == .21 ? '('+ _model.businessBuilding.leg[0].perfPct * 100 +'%) Q':'('+ _model.businessBuilding.leg[0].perfPct * 100 +'%)';
		var legTwoPercent = _model.businessBuilding.leg[1].perfPct == .21 ? '('+ _model.businessBuilding.leg[1].perfPct * 100 +'%) Q':'('+ _model.businessBuilding.leg[1].perfPct * 100 +'%)';
		var legThreePercent = _model.businessBuilding.leg[2].perfPct == .21 ? '('+ _model.businessBuilding.leg[2].perfPct * 100 +'%) Q':'('+ _model.businessBuilding.leg[2].perfPct * 100 +'%)';
		
		$('.leg-1-slider .percent').text(legOnePercent);
		$('.leg-2-slider .percent').text(legTwoPercent);
		$('.leg-3-slider .percent').text(legThreePercent);
		
		$('#business-building-content-total-retail-sales .value').text(retailSales);
		$('#business-building-content-retail-margin .value').text(_model.businessBuilding.retailMargin + "%");
		$('#business-building-content-total-retail-profit .value').text(retailProfit);
		
		$('#business-building-content-personal-performance-bonus .label .percent').text('('+_model.businessBuilding.perfBnsPct * 100+'%)');
		$('#business-building-content-personal-performance-bonus .sub-label .percent').text(+_model.businessBuilding.perfBnsPct * 100+'%!');
		$('#business-building-content-personal-performance-bonus .value').text(personalPerformanceBonus);
		
		$('#business-building-content-differential-performance-bonus .value').text(passupPerformanceBonus);
		$('#business-building-content-ruby-bonus .value').text(rubyBonus);
		$('#business-building-content-leadership-bonus .value').text(leadershipBonus);
		
		$('#business-building-content-personal-performance-bonus .sub-label').hide();
		
		if(_model.businessBuilding.perfBnsPct >= .21)
		{
			$('#business-building-content-leadership-bonus .percent').text(_model.bonuses.leadership[0] * 100 +'%');
			$('#business-building-content-personal-performance-bonus .sub-label').show();
		}
		
		$('#business-building-income-bar .bubble-text .value').text(monthlyIncome);
		$('#business-building-content-summary-monthly-income .bubble-text .value').text(monthlyIncome);
		$('#business-building-content-summary-annual-income .value').text(annualIncome);
		
		
		
		var maxMonthlyIncome = Math.max(_model.businessBuilding.monthlyIncome, _model.businessBuilding.maxMonthlyIncome);
		var totalMonthlyIncomeWidth = (_model.businessBuilding.monthlyIncome / maxMonthlyIncome) * _myGoalsBarMaxWidth;
		
		var retailProfitWidth = (_model.businessBuilding.totalRetailProfit / _model.businessBuilding.monthlyIncome) * totalMonthlyIncomeWidth;
		var personalPerformanceWidth = (_model.businessBuilding.personalPerfBonus / _model.businessBuilding.monthlyIncome) * totalMonthlyIncomeWidth;
		var passupPerformanceWidth = (_model.businessBuilding.passupPerfBonus / _model.businessBuilding.monthlyIncome) * totalMonthlyIncomeWidth;
		var rubyWidth = (_model.businessBuilding.rubyBonus / _model.businessBuilding.monthlyIncome) * totalMonthlyIncomeWidth;
		var leadershipWidth = (_model.businessBuilding.leadershipBonus / _model.businessBuilding.monthlyIncome) * totalMonthlyIncomeWidth;

		$('#business-building-income-bar .bar .display .retail-profit').width(retailProfitWidth);
		$('#business-building-income-bar .bar .display .personal-performance').width(personalPerformanceWidth);
		$('#business-building-income-bar .bar .display .passup-performance').width(passupPerformanceWidth);
		$('#business-building-income-bar .bar .display .ruby').width(rubyWidth);
		$('#business-building-income-bar .bar .display .leadership').width(leadershipWidth);
		
		
	};
	
	var _updatePrintView = function()
	{
		$('.print .my-goals .monthly-income .value').text(_formatMoney(_model.myGoals.desiredIncome));
		$('.print .my-goals .number-of-clients .value').text(_model.myGoals.numberOfClients);
		$('.print .my-goals .sales-per-client .value').text(_formatMoney(_model.myGoals.salesPerClient));
		$('.print .my-goals .product-category .value').text(_model.myGoals.category.name);
		
		$('.print .my-goals .product-list ul').html('');
		
		for (var i = 0; i < _model.myGoals.category.products.length; i++)
		{
			var product = _model.myGoals.category.products[i];
			var li = '<li class="clear"><span class="label">'+product.name+':</span><span class="value">'+Math.ceil(product.myGoalsTotalProductCount)+'</span></li>';
			$('.print .my-goals .product-list ul').append(li);
		}
		
		
		$('.print .my-goals .retail-sales .value').text(_formatMoney(_model.myGoals.totalRetailSales));
		$('.print .my-goals .retail-margin .value').text(_model.myGoals.retailMargin+'%');
		$('.print .my-goals .retail-profit .value').text(_formatMoney(_model.myGoals.totalRetailProfit));
		$('.print .my-goals .monthly-income .value').text(_formatMoney(_model.myGoals.desiredIncome));
		$('.print .my-goals .yearly-income .value').text(_formatMoney(_model.myGoals.annualIncome));
		
		$('.print .retailing .personal-monthly-orders .value').text(_formatMoney(_model.retailing.personalOrders));
		$('.print .retailing .number-of-clients .value').text(_model.retailing.numberOfClients);
		$('.print .retailing .sales-per-client .value').text(_formatMoney(_model.retailing.salesPerClient));
		$('.print .retailing .product-category .value').text(_model.retailing.category.name);
		
		$('.print .retailing .product-list ul').html('');
		for (var j = 0; j < _model.retailing.category.products.length; j++)
		{
			var product = _model.retailing.category.products[j];
			var li = '<li class="clear"><span class="label">'+product.name+':</span><span class="value">'+Math.ceil(product.retailingTotalProductCount)+'</span></li>';
			$('.print .retailing .product-list ul').append(li);
		}
		
		$('.print .retailing .retail-sales .value').text(_formatMoney(_model.retailing.totalRetailSales));
		$('.print .retailing .retail-margin .value').text(_model.retailing.retailMargin +'%');
		$('.print .retailing .retail-profit .value').text(_formatMoney(_model.retailing.totalRetailProfit));
		$('.print .retailing .personal-performance-bonus .value').text(_formatMoney(_model.retailing.perfBnsAmt));
		$('.print .retailing .monthly-income .value').text(_formatMoney(_model.retailing.monthlyIncome));
		$('.print .retailing .yearly-income .value').text(_formatMoney(_model.retailing.annualIncome));
		
		$('.print .business-building .personal-monthly-orders .value').text(_formatMoney(_model.businessBuilding.personalOrders));
		$('.print .business-building .number-of-clients .value').text(_model.businessBuilding.numberOfClients);
		$('.print .business-building .sales-per-client .value').text(_formatMoney(_model.businessBuilding.salesPerClient));
		$('.print .business-building .leg-1 .value').text(_formatMoney(_model.businessBuilding.legRetail[0]));
		$('.print .business-building .leg-2 .value').text(_formatMoney(_model.businessBuilding.legRetail[1]));
		$('.print .business-building .leg-3 .value').text(_formatMoney(_model.businessBuilding.legRetail[2]));
		$('.print .business-building .retail-sales .value').text(_formatMoney(_model.businessBuilding.totalRetailSales));
		$('.print .business-building .retail-margin .value').text(_model.businessBuilding.retailMargin +'%');
		$('.print .business-building .retail-profit .value').text(_formatMoney(_model.businessBuilding.totalRetailProfit));
		$('.print .business-building .personal-performance-bonus .value').text(_formatMoney(_model.businessBuilding.personalPerfBonus));
		$('.print .business-building .differential-performance-bonus .value').text(_formatMoney(_model.businessBuilding.passupPerfBonus));
		$('.print .business-building .ruby-bonus .value').text(_formatMoney(_model.businessBuilding.rubyBonus));
		$('.print .business-building .leadership-bonus .value').text(_formatMoney(_model.businessBuilding.leadershipBonus));
		$('.print .business-building .monthly-income .value').text(_formatMoney(_model.businessBuilding.monthlyIncome));
		$('.print .business-building .yearly-income .value').text(_formatMoney(_model.businessBuilding.annualIncome));
	};

	var _updateMyGoalsModel = function()
	{
		_model.myGoals.totalRetailSales = 0;
		_model.myGoals.totalRetailProfit = 0;
		
		for(var i = 0; i < _model.myGoals.category.products.length; i++)
		{
			var product = _model.myGoals.category.products[i];
			var weightedRetailIncome = product.weighting * _model.myGoals.desiredIncome;
			
			product.myGoalsTotalProductCount = weightedRetailIncome / product.markup;
			
			_model.myGoals.totalRetailProfit += product.markup * product.myGoalsTotalProductCount;
			_model.myGoals.totalRetailSales += product.sr * product.myGoalsTotalProductCount;
			_model.myGoals.numberOfClients = Math.round(_model.myGoals.totalRetailSales / _model.myGoals.averageSalesPerClient);
			_model.myGoals.salesPerClient = _model.myGoals.totalRetailSales / _model.myGoals.numberOfClients;
			_model.myGoals.salesPerClient = isNaN(_model.myGoals.salesPerClient) || !isFinite(_model.myGoals.salesPerClient)?0:_model.myGoals.salesPerClient;
		}
		
		_model.myGoals.annualIncome = _model.myGoals.totalRetailProfit * 12;
		var retailMargin = Math.round((_model.myGoals.totalRetailProfit / (_model.myGoals.totalRetailSales - _model.myGoals.totalRetailProfit)) * 100);
		_model.myGoals.retailMargin = isNaN(retailMargin) ? 0 : retailMargin;

	};
	
	var _updateRetailingModel = function()
	{
		_model.retailing.totalRetailSales = 0;
		_model.retailing.totalRetailProfit = 0;
		_model.retailing.totalPV = 0;
		_model.retailing.totalBV = 0;
		
		for (var i = 0; i < _model.retailing.category.products.length; i++) 
		{
			var product = _model.retailing.category.products[i];
			var weightedRetailSales = _model.retailing.salesPerClient * _model.retailing.numberOfClients * product.weighting;
			var weightedPersonalOrders = _model.retailing.personalOrders * product.weighting;
			var retailProductCount = weightedRetailSales / product.sr;
			var personalProductCount = weightedPersonalOrders / product.dc;
			var totalProductCount = retailProductCount + personalProductCount;
			var retailSalesFromProductCount = retailProductCount * product.sr;
			var markupFromProductCount = retailProductCount * product.markup;
			
			_model.retailing.totalRetailProfit += markupFromProductCount;
			_model.retailing.totalRetailSales += retailSalesFromProductCount;
			
			product.retailingTotalProductCount = retailProductCount + personalProductCount;
			_model.retailing.totalPV += product.pv * totalProductCount;
			_model.retailing.totalBV += product.bv * totalProductCount;
		}
		
		// performance bonus calculation
		_model.retailing.perfBnsPct = _getPerformanceBonus(_model.retailing.totalPV);
		
		_model.retailing.perfBnsAmt = _model.retailing.totalBV * _model.retailing.perfBnsPct;
		_model.retailing.monthlyIncome = _model.retailing.perfBnsAmt + _model.retailing.totalRetailProfit;
		_model.retailing.annualIncome = _model.retailing.monthlyIncome * 12;
		
		var retailMargin = Math.round((_model.retailing.totalRetailProfit / (_model.retailing.totalRetailSales - _model.retailing.totalRetailProfit)) * 100);
		_model.retailing.retailMargin = isNaN(retailMargin) ? 0 : retailMargin;
	};
	
	var _getMaxRetailingMonthlyIncome = function()
	{
		var personalOrders = _model.retailing.maxPersonalOrders;
		var numberOfClients = _model.retailing.maxNumberOfClients;
		var salesPerClient = _model.retailing.maxSalesPerClient;
		var totalRetailProfit = 0;
		var totalPV = 0;
		var totalBV = 0;
		
		for (var i = 0; i < _model.retailing.category.products.length; i++) 
		{
			var product = _model.retailing.category.products[i];
			var weightedRetailSales = salesPerClient * numberOfClients * product.weighting;
			var weightedPersonalOrders = personalOrders * product.weighting;
			var retailProductCount = weightedRetailSales / product.sr;
			var personalProductCount = weightedPersonalOrders / product.dc;
			var totalProductCount = retailProductCount + personalProductCount;
			//var retailSalesFromProductCount = retailProductCount * product.sr;
			var markupFromProductCount = retailProductCount * product.markup;
			
			totalRetailProfit += markupFromProductCount;

			totalPV += product.pv * totalProductCount;
			totalBV += product.bv * totalProductCount;
		}
		
		// performance bonus calculation
		var performanceBonus = totalBV * _getPerformanceBonus(totalPV);
		var monthlyIncome = performanceBonus + totalRetailProfit;
		return monthlyIncome;
	};
	
	var _updateBusinessBuildingModel = function()
	{
		_model.businessBuilding.totalRetailSales = _model.businessBuilding.numberOfClients * _model.businessBuilding.salesPerClient;
		
		var totalLegBV = 0;
		var totalLegPV = 0;
		var totalLegPerfBonus = 0;
		var totalShipPerfBonusPV = 0;
		var totalShipPerfBonusBV = 0;
		var totalPerfBonusFromDownline = 0;
		var totalPersonalPerfBonus = 0;
		var totalRubyPV = 0;
		var totalRubyBV = 0;
		var totalShipPVToShipUpline = 0;
		var totalShipBVToShipUpline = 0;
		var totalLeadershipPVFromDownline = 0;
		var totalLeadershipBVFromDownline = 0;
		var totalLeadershipBonusFromDownline = 0;
		var totalLeadershipBonusAdjustment = 0;
		
		var maxPerfBonusPct = _model.bonuses.perfSchedules[_model.bonuses.perfSchedules.length - 1][1];
		
		var personalOrdersDistCost = _model.businessBuilding.personalOrders;
		var personalOrdersBV = personalOrdersDistCost / _model.businessBuilding.ratios.dcbv;
		var personalOrdersPV = personalOrdersBV / _model.businessBuilding.ratios.bvpv;
		
		var retailDistCost = _model.businessBuilding.totalRetailSales / _model.businessBuilding.ratios.srdc;
		var retailBV = retailDistCost / _model.businessBuilding.ratios.dcbv;
		var retailPV = retailBV / _model.businessBuilding.ratios.bvpv;
		
		var personalBV = personalOrdersBV + retailBV;
		var personalPV = personalOrdersPV + retailPV;
		
		totalShipPerfBonusBV += personalBV;
		totalShipPerfBonusPV += personalPV;
		
		
		var leg = [];
		var n = 3;
		
		var maxLegPerfBnsPct = 0;
		
		for(var i = 0; i < n; i++)
		{
			var distCost = _model.businessBuilding.legRetail[i] / _model.businessBuilding.ratios.srdc;
			var bv = distCost / _model.businessBuilding.ratios.dcbv;
			var pv = bv / _model.businessBuilding.ratios.bvpv;
			var perfPct = _getPerformanceBonus(pv);
			var perfBonus = bv * perfPct;
			var shipPerfBnsGrpPV = perfPct < maxPerfBonusPct ? pv : 0;
			var shipPerfBnsGrpBV = pv > 0 ? bv : 0;
			
			if(perfPct > maxLegPerfBnsPct)
			{
				maxLegPerfBnsPct = perfPct;
			}
			
			totalShipPerfBonusPV += shipPerfBnsGrpPV;
			totalShipPerfBonusBV += shipPerfBnsGrpBV;
			totalLegBV += bv;
			totalLegPV += pv;
			
			totalLegPerfBonus += perfBonus;
			
			leg[i] = {
				'distCost': distCost,
				'bv': bv,
				'pv': pv,
				'perfPct': perfPct,
				'perfBonus': perfBonus,
				'shipPerfBnsGrpPV': shipPerfBnsGrpPV,
				'shipPerfBnsGrpBV': shipPerfBnsGrpBV
			};
			
			
		}
		
		_model.businessBuilding.leg = leg;
		
		var shipPerfBnsPct = maxLegPerfBnsPct == maxPerfBonusPct ? maxPerfBonusPct : _getPerformanceBonus(totalShipPerfBonusPV);
		var personalPerfBonus = personalBV * shipPerfBnsPct;
		totalPersonalPerfBonus += personalPerfBonus;
		
		
		totalRubyPV += personalPV;
		totalRubyBV +=  personalBV;
		
		
		var personalShipPVToShipUpline = shipPerfBnsPct == _model.bonuses.leadership[0] ? personalPV : 0;
		totalShipPVToShipUpline += personalShipPVToShipUpline;
		
		
		var personalShipBVToShipUpline = personalShipPVToShipUpline > 0 ? personalBV : 0;
		totalShipBVToShipUpline += personalShipBVToShipUpline;
		
		var legLeadershipBonusAdjustment = 0;
		var legLeadershipBonusAdjustmentCount = 0;
		
		for(var j = 0; j < n; j++)
		{
			var perfBonusFromDownline = (shipPerfBnsPct - leg[j]['perfPct']) * leg[j]['shipPerfBnsGrpBV'];
			totalPerfBonusFromDownline += perfBonusFromDownline;
			
			var rubyPV = leg[j]['perfPct'] < maxPerfBonusPct ? leg[j]['pv'] : 0;
			totalRubyPV += rubyPV;
			
			var rubyBV = rubyPV > 0 ? leg[j]['bv'] : 0;
			totalRubyBV += rubyBV;
			
			var shipPVToShipUpline = leg[j]['perfPct'] < _model.bonuses.leadership[0] ? leg[j]['pv'] : 0;
			totalShipPVToShipUpline += shipPVToShipUpline;
			
			var shipBVToShipUpline = shipPVToShipUpline > 0 ? leg[j]['bv'] : 0;
			totalShipBVToShipUpline += shipBVToShipUpline;
			
			var leadershipPVFromDownline = leg[j]['perfPct'] == _model.bonuses.leadership[0] ? leg[j]['pv'] : 0;
			totalLeadershipPVFromDownline += leadershipPVFromDownline;
			
			var leadershipBVFromDownline = leadershipPVFromDownline > 0 ? leg[j]['bv'] : 0;
			totalLeadershipBVFromDownline += leadershipBVFromDownline;
			
			var leadershipBonusFromDownline = leadershipBVFromDownline * _model.bonuses.leadership[2];
			totalLeadershipBonusFromDownline += leadershipBonusFromDownline;
			
			var leadershipBonusAdjustment = leadershipBonusFromDownline > 0 ? Math.min(leadershipBonusFromDownline, _model.bonuses.leadership[1]) : 0;
			
			totalLeadershipBonusAdjustment += leadershipBonusAdjustment;
			legLeadershipBonusAdjustment += leadershipBonusAdjustment;
			legLeadershipBonusAdjustmentCount += leadershipBonusAdjustment > 0 ? 1 : 0;
		}
		
		var rubyBonus = totalRubyPV >= _model.bonuses.ruby[0] ? totalRubyBV * _model.bonuses.ruby[1] : 0;
		var leadershipBonusUpline = shipPerfBnsPct == _model.bonuses.leadership[0] ? totalShipBVToShipUpline * _model.bonuses.leadership[2] : 0;
		
		var personalLeadershipBonusAdjustment = leadershipBonusUpline > 0 ? Math.min(leadershipBonusUpline, _model.bonuses.leadership[1]) : 0;
		totalLeadershipBonusAdjustment += personalLeadershipBonusAdjustment;
		
		var averageLegLeadershipBonusAdjustmet = Math.max(legLeadershipBonusAdjustment / legLeadershipBonusAdjustmentCount, 0);
		
		var leadershipBonusOptions = [];
		leadershipBonusOptions[0] = totalShipPVToShipUpline >= _model.bonuses.leadership[3] ? totalLeadershipBonusFromDownline : 0;
		
		if(totalShipPVToShipUpline >= _model.bonuses.leadership[4])
		{
			leadershipBonusOptions[1] = totalShipPVToShipUpline < _model.bonuses.leadership[3] ? totalLeadershipBonusFromDownline - (_model.bonuses.leadership[1] - leadershipBonusUpline):0;
		}
		else
		{
			leadershipBonusOptions[1] = 0;
		}
		
		if(totalShipPVToShipUpline < _model.bonuses.leadership[4])
		{
			leadershipBonusOptions[2] = legLeadershipBonusAdjustmentCount > 1 ? totalLeadershipBonusFromDownline - (_model.bonuses.leadership[1] - leadershipBonusUpline) : 0;
		}
		else
		{
			leadershipBonusOptions[2] = 0;
		}
		
		var totalLeadershipOptions = 0;
		
		for(var k = 0; k < leadershipBonusOptions.length; k++)
		{
			totalLeadershipOptions += leadershipBonusOptions[k];
		}
		
		_model.businessBuilding.totalRetailProfit = _model.businessBuilding.totalRetailSales - retailDistCost;
		_model.businessBuilding.retailMargin = Math.round((_model.businessBuilding.ratios.srdc - 1) * 100);
		_model.businessBuilding.perfBnsPct = shipPerfBnsPct;
		_model.businessBuilding.personalPerfBonus = totalPersonalPerfBonus;
		_model.businessBuilding.passupPerfBonus = totalPerfBonusFromDownline;
		_model.businessBuilding.leadershipBonus = totalLeadershipOptions > 0 ? totalLeadershipOptions : 0;
		_model.businessBuilding.rubyBonus = rubyBonus;
		_model.businessBuilding.monthlyIncome = _model.businessBuilding.totalRetailProfit + _model.businessBuilding.personalPerfBonus + _model.businessBuilding.passupPerfBonus + _model.businessBuilding.leadershipBonus + _model.businessBuilding.rubyBonus; 
		_model.businessBuilding.annualIncome = _model.businessBuilding.monthlyIncome * 12;
	};
	
	var _getMaxBusinessBuildingMonthlyIncome = function()
	{
		var totalRetailSales = _model.businessBuilding.maxNumberOfClients * _model.businessBuilding.maxSalesPerClient;
		var personalOrders = _model.businessBuilding.maxPersonalOrders;
		var totalRetailProfit = 0;
		var totalLegBV = 0;
		var totalLegPV = 0;
		var totalLegPerfBonus = 0;
		var totalShipPerfBonusPV = 0;
		var totalShipPerfBonusBV = 0;
		var totalPerfBonusFromDownline = 0;
		var totalPersonalPerfBonus = 0;
		var totalRubyPV = 0;
		var totalRubyBV = 0;
		var totalShipPVToShipUpline = 0;
		var totalShipBVToShipUpline = 0;
		var totalLeadershipPVFromDownline = 0;
		var totalLeadershipBVFromDownline = 0;
		var totalLeadershipBonusFromDownline = 0;
		var totalLeadershipBonusAdjustment = 0;
		
		var maxPerformanceBonusPercent = _model.bonuses.perfSchedules[_model.bonuses.perfSchedules.length - 1][1];
		
		
		var personalOrdersBV = personalOrders / _model.businessBuilding.ratios.dcbv;
		var personalOrdersPV = personalOrdersBV / _model.businessBuilding.ratios.bvpv;
		var retailDistCost = totalRetailSales / _model.businessBuilding.ratios.srdc;
		var retailBV = retailDistCost / _model.businessBuilding.ratios.dcbv;
		var retailPV = retailBV / _model.businessBuilding.ratios.bvpv;
		
		var personalBV = personalOrdersBV + retailBV;
		var personalPV = personalOrdersPV + retailPV;
		
		totalShipPerfBonusBV += personalBV;
		totalShipPerfBonusPV += personalPV;
		
		var leg = [];
		var n = 3;
		
		var maxLegPerfBnsPct = 0;
		
		for(var i = 0; i < n; i++)
		{
			var distCost = _model.businessBuilding.maxRetailPerLeg / _model.businessBuilding.ratios.srdc;
			var bv = distCost / _model.businessBuilding.ratios.dcbv;
			var pv = bv / _model.businessBuilding.ratios.bvpv;
			var perfPct = _getPerformanceBonus(pv);
			var perfBonus = bv * perfPct;
			var shipPerfBnsGrpPV = perfPct < maxPerformanceBonusPercent ? pv : 0;
			var shipPerfBnsGrpBV = pv > 0 ? bv : 0;
			
			if(perfPct > maxLegPerfBnsPct)
			{
				maxLegPerfBnsPct = perfPct;
			}
			
			totalShipPerfBonusPV += shipPerfBnsGrpPV;
			totalShipPerfBonusBV += shipPerfBnsGrpBV;
			totalLegBV += bv;
			totalLegPV += pv;
			
			totalLegPerfBonus += perfBonus;
			
			leg[i] = {
				'distCost': distCost,
				'bv': bv,
				'pv': pv,
				'perfPct': perfPct,
				'perfBonus': perfBonus,
				'shipPerfBnsGrpPV': shipPerfBnsGrpPV,
				'shipPerfBnsGrpBV': shipPerfBnsGrpBV
			};
		}
		
		
		var shipPerfBnsPct = maxLegPerfBnsPct == maxPerformanceBonusPercent ? maxPerformanceBonusPercent : _getPerformanceBonus(totalShipPerfBonusPV);
		
		totalPersonalPerfBonus += personalBV * shipPerfBnsPct;
		
		
		totalRubyPV += personalPV;
		totalRubyBV += personalBV;
		
		
		var personalShipPVToShipUpline = shipPerfBnsPct == _model.bonuses.leadership[0] ? personalPV : 0;
		totalShipPVToShipUpline += personalShipPVToShipUpline;
		
		
		var personalShipBVToShipUpline = personalShipPVToShipUpline > 0 ? personalBV : 0;
		totalShipBVToShipUpline += personalShipBVToShipUpline;
		
		var legLeadershipBonusAdjustment = 0;
		var legLeadershipBonusAdjustmentCount = 0;
		
		for(var j = 0; j < n; j++)
		{
			var perfBonusFromDownline = (shipPerfBnsPct - leg[j]['perfPct']) * leg[j]['shipPerfBnsGrpBV'];
			totalPerfBonusFromDownline += perfBonusFromDownline;
			
			var rubyPV = leg[j]['perfPct'] < maxPerformanceBonusPercent ? leg[j]['pv'] : 0;
			totalRubyPV += rubyPV;
			
			var rubyBV = rubyPV > 0 ? leg[j]['bv'] : 0;
			totalRubyBV += rubyBV;
			
			var shipPVToShipUpline = leg[j]['perfPct'] < _model.bonuses.leadership[0] ? leg[j]['pv'] : 0;
			totalShipPVToShipUpline += shipPVToShipUpline;
			
			var shipBVToShipUpline = shipPVToShipUpline > 0 ? leg[j]['bv'] : 0;
			totalShipBVToShipUpline += shipBVToShipUpline;
			
			var leadershipPVFromDownline = leg[j]['perfPct'] == _model.bonuses.leadership[0] ? leg[j]['pv'] : 0;
			totalLeadershipPVFromDownline += leadershipPVFromDownline;
			
			var leadershipBVFromDownline = leadershipPVFromDownline > 0 ? leg[j]['bv'] : 0;
			totalLeadershipBVFromDownline += leadershipBVFromDownline;
			
			var leadershipBonusFromDownline = leadershipBVFromDownline * _model.bonuses.leadership[2];
			totalLeadershipBonusFromDownline += leadershipBonusFromDownline;
			
			var leadershipBonusAdjustment = leadershipBonusFromDownline > 0 ? Math.min(leadershipBonusFromDownline, _model.bonuses.leadership[1]) : 0;
			
			totalLeadershipBonusAdjustment += leadershipBonusAdjustment;
			legLeadershipBonusAdjustment += leadershipBonusAdjustment;
			legLeadershipBonusAdjustmentCount += leadershipBonusAdjustment > 0 ? 1 : 0;
		}
		
		var rubyBonus = totalRubyPV >= _model.bonuses.ruby[0] ? totalRubyBV * _model.bonuses.ruby[1] : 0;
		var leadershipBonusUpline = shipPerfBnsPct == _model.bonuses.leadership[0] ? totalShipBVToShipUpline * _model.bonuses.leadership[2] : 0;
		
		var personalLeadershipBonusAdjustment = leadershipBonusUpline > 0 ? Math.min(leadershipBonusUpline, _model.bonuses.leadership[1]) : 0;
		totalLeadershipBonusAdjustment += personalLeadershipBonusAdjustment;
		
		var averageLegLeadershipBonusAdjustmet = legLeadershipBonusAdjustment / legLeadershipBonusAdjustmentCount;
		
		var leadershipBonusOptions = [];
		leadershipBonusOptions[0] = totalShipPVToShipUpline >= _model.bonuses.leadership[3] ? totalLeadershipBonusFromDownline : 0;
		
		if(totalShipPVToShipUpline >= _model.bonuses.leadership[4])
		{
			leadershipBonusOptions[1] = totalShipPVToShipUpline < _model.bonuses.leadership[3] ? totalLeadershipBonusFromDownline - (_model.bonuses.leadership[1] - leadershipBonusUpline):0;
		}
		else
		{
			leadershipBonusOptions[1] = 0;
		}
		
		if(totalShipPVToShipUpline < _model.bonuses.leadership[4])
		{
			leadershipBonusOptions[2] = legLeadershipBonusAdjustmentCount > 1 ? totalLeadershipBonusFromDownline - (_model.bonuses.leadership[1] - leadershipBonusUpline) : 0;
		}
		else
		{
			leadershipBonusOptions[2] = 0;
		}
		
		var totalLeadershipBonus = 0;
		
		for(var k = 0; k < leadershipBonusOptions.length; k++)
		{
			totalLeadershipBonus += leadershipBonusOptions[k];
		}
		
		totalRetailProfit = totalRetailSales - retailDistCost;

		var monthlyIncome = totalRetailProfit + totalPersonalPerfBonus + totalPerfBonusFromDownline + totalLeadershipBonus + rubyBonus; 
		return monthlyIncome;
	};
	
	var _getPerformanceBonus = function(pv)
	{
		var n = _model.bonuses.perfSchedules.length;
		
		for(var i = 0; i < n; i++)
		{
			if((i+1) < n)
			{
				var perf = _model.bonuses.perfSchedules[i];
				var nextPerf = _model.bonuses.perfSchedules[i+1];
				
				if(pv >= perf[0] && pv < nextPerf[0])
				{
					return perf[1];
				}
				continue;
			}
			
			return _model.bonuses.perfSchedules[n - 1][1];
		}
	};
	
	var _setProductCategory = function(index, tab)
	{	
		_model[tab].category = _settings.productCategories[index];
		_updateModel(tab);
		switch(tab)
		{
			case 'retailing':
				_model.retailing.maxMonthlyIncome = _getMaxRetailingMonthlyIncome();
				break;
		}
		_updateView(tab);
	};
		
	var _updateModel = function(model)
	{
		switch(model)
		{
			case 'myGoals':
				_updateMyGoalsModel();
				break;
			case 'retailing':
				_updateRetailingModel();
				break;
			case 'businessBuilding':
				_updateBusinessBuildingModel();
				break;
			default:
				_updateMyGoalsModel();
				_updateRetailingModel();
				_updateBusinessBuildingModel();
				break;
		}
	};
	
	var _updateView = function(view)
	{
		switch(view)
		{
			case 'myGoals':
				_updateMyGoalsView();
				break;
			case 'retailing':
				_updateRetailingView();
				break;
			case 'businessBuilding':
				_updateBusinessBuildingView();
				break;
			case 'print':
				_updatePrintView();
				break;
			default:
				_updateMyGoalsView();
				_updateRetailingView();
				_updateBusinessBuildingView();
				_updatePrintView();
				break;
		}
	};
	
	var _update = function(section)
	{
		_updateModel(section);
		_updateView(section);
	};
	
	var _showTabIndex = function(index)
	{
		// hide all content
		$('.simulator-content').hide();
		
		// deselect nav buttons
		$('#simulator-tab-1').parent().removeClass('selected');
		$('#simulator-tab-2').parent().removeClass('selected');
		$('#simulator-tab-3').parent().removeClass('selected');
		
		$('#simulator-tab-'+(index+1)).parent().addClass('selected');
		
		if(_currentTab != null)
		{
			$(_currentTab).fadeOut(300, function(){
				_currentTab = null;
				_showTabIndex(index);
			});
			
			
			return;
		}
		
		$('.print-block').addClass('hidden');
		
		switch(index)
		{
			case 0:
				$('.my-goals.print-block').removeClass('hidden');
				break;
			case 1:
				$('.retailing.print-block').removeClass('hidden');
				break;
			case 2:
				$('.business-building.print-block').removeClass('hidden');
				break;
		}
		
		var el = $('.simulator-content').get(index);
		_currentTab = el;
		$(_currentTab).fadeIn(300);
	};
	
	var _initUI = function()
	{
		// hide simulator content
		$('.simulator-content').hide();
		
		// tooltips
		$('#my-goals-retail-margin a.q').tipTip({
			defaultPosition: 'right',
			content: $('#my-goals-retail-margin-tooltip').html()
		});
		
		$('#retailing-retail-margin a.q').tipTip({
			defaultPosition: 'right',
			content: $('#retailing-retail-margin-tooltip').html()
		});
		
		
		
		$('#business-building-content-retail-margin a.q').tipTip({
			defaultPosition: 'right',
			content: $('#business-building-retail-margin-tooltip').html()
		});
		
		$('#business-building-content-ruby-bonus a.q').tipTip({
			defaultPosition: 'right',
			content: $('#business-building-ruby-tooltip').html()
		});
		
		$('#business-building-content-leadership-bonus a.q').tipTip({
			defaultPosition: 'right',
			content: $('#business-building-leadership-tooltip').html()
		});
		
		$('#business-building-legs h3 a.q').tipTip({
			defaultPosition: 'right',
			content: $('#business-building-legs-tooltip').html()
		});
		
		$('#business-building-sliders h3 a.q').tipTip({
			defaultPosition: 'right',
			content: $('#business-building-sliders-tooltip').html()
		});
		
		$('#my-goals-monthly-earnings h3 a.q').tipTip({
			defaultPosition: 'right',
			content: $('#my-goals-monthly-earnings-tooltip').html()
		});
		
		$('#my-goals-client-number h3 a.q').tipTip({
			defaultPosition: 'right',
			content: $('#my-goals-client-number-tooltip').html()
		});
		
		$('#my-goals-product-category h3 a.q').tipTip({
			defaultPosition: 'right',
			content: $('#my-goals-product-category-tooltip').html()
		});
		
		$('#retailing-sliders-info a.q').tipTip({
			defaultPosition: 'right',
			content: $('#retailing-sliders-tooltip').html()
		});
		
		$('#retailing-currency a.q').tipTip({
			defaultPosition: 'right',
			content: $('#retailing-currency-tooltip').html()
		});
		
		$('#retailing-product-category h3 a.q').tipTip({
			defaultPosition: 'right',
			content: $('#retailing-product-category-tooltip').html()
		});
		
		$('.my-goals .footer-block .next-stage-button').tipTip({
			defaultPosition: 'top',
			content: $('#my-goals-next-stage-tooltip').html()
		});
		
		$('.retailing .footer-block .next-stage-button').tipTip({
			defaultPosition: 'top',
			content: $('#retailing-next-stage-tooltip').html()
		});
		
		$('.business-building .footer-block .next-stage-button').tipTip({
			defaultPosition: 'top',
			content: $('#business-building-next-stage-tooltip').html()
		});
		
		$('.estimated-quantity-tooltip').tipTip({
			defaultPosition: 'right',
			content: $('#estimated-quantity-tooltip').html()
		});
		
		$('.personal-performance-bonus-tooltip').tipTip({
			defaultPosition: 'right',
			content: $('#personal-performance-bonus-tooltip').html()
		});
		
		$('.business-building-monthly-income-tooltip').tipTip({
			defaultPosition: 'right',
			content: $('#business-building-monthly-income-tooltip').html()
		});
		
		$('.differential-performance-bonus-tooltip').tipTip({
			defaultPosition: 'right',
			content: $('#differential-performance-bonus-tooltip').html()
		});
		
		$('.business-building-yearly-income-tooltip').tipTip({
			defaultPosition: 'right',
			content: $('#business-building-yearly-income-tooltip').html()
		});
		
		$('.business-building-currency-tooltip').tipTip({
			defaultPosition: 'right',
			content: $('#currency-tooltip').html()
		});
		
		$('.my-goals-currency-tooltip').tipTip({
			defaultPosition: 'right',
			content: $('#currency-tooltip').html()
		});
		
		$('.retailing-currency-tooltip').tipTip({
			defaultPosition: 'right',
			content: $('#currency-tooltip').html()
		});
		
		// Detect browser
		var IE6 = (navigator.appVersion.indexOf("MSIE 6.")==-1) ? false : true;
		var IE7 = (navigator.appVersion.indexOf("MSIE 7.")==-1) ? false : true;
		
		// Using either IE6 or IE7
		var IE = IE6 || IE7;
		
		// My Goals
		$('#my-goals-monthly-earnings .slider').slider({
			slide: function(evt, ui){
				if(!IE)
				{
					_model.myGoals.desiredIncome = ui.value;
					_update('myGoals');
					
					_model.retailing.numberOfClients = _model.myGoals.numberOfClients;
					_model.retailing.salesPerClient = _model.myGoals.salesPerClient;
					
					_update('retailing');
					
					$('.retailing-number-of-clients-slider .slider').slider({value: _model.retailing.numberOfClients});
					$('.retailing-sales-per-client-slider .slider').slider({value: _model.retailing.salesPerClient});
					
					_model.businessBuilding.numberOfClients = _model.myGoals.numberOfClients;
					_model.businessBuilding.salesPerClient = _model.myGoals.salesPerClient;
					
					_update('businessBuilding');
					
					$('.business-building-number-of-clients-slider .slider').slider({value: _model.businessBuilding.numberOfClients});
					$('.business-building-sales-per-client-slider .slider').slider({value: _model.businessBuilding.salesPerClient});
				}
			},
			change: function(evt, ui)
			{
				_updateView('print');
				
				if(IE)
				{
					_model.myGoals.desiredIncome = ui.value;
					_update('myGoals');
				}
			},
			min: 0, 
			max: _model.myGoals.maxMonthlyIncome, 
			step: _settings.simulatorSettings.myGoals.monthlyIncomeSliderStep
		});
		
		// Retailing
		$('.retailing-personal-orders-slider .slider').slider(
		{
			slide: function(evt, ui){
				if(!IE){
					_model.retailing.personalOrders = ui.value;
					_update('retailing');
				}
				
			}, 
			change: function(evt, ui){
				if(evt.originalEvent)
				{
					if(IE){
						_model.retailing.personalOrders = ui.value;
						_update('retailing');
					}
				
					$('.business-building-personal-orders-slider .slider').slider({value: ui.value});
					_model.businessBuilding.personalOrders = ui.value;
					_update('businessBuilding');
					_updateView('print');
					return;
				}
			},
			min: 0, 
			max: _model.retailing.maxPersonalOrders,
			step:  _settings.simulatorSettings.retailing.personalOrdersSliderStep
		});
		
		$('.retailing-number-of-clients-slider .slider').slider(
		{
			slide: function(evt, ui){
				if (!IE) {
					_model.retailing.numberOfClients = ui.value;
					_update('retailing');
				}
				
			},
			change: function(evt, ui){
				if(evt.originalEvent)
				{
					if (IE) {
						_model.retailing.numberOfClients = ui.value;
						_update('retailing');
					}
					
					$('.business-building-number-of-clients-slider .slider').slider({value: ui.value});
					_model.businessBuilding.numberOfClients = ui.value;
					_update('businessBuilding');
					_updateView('print');
					return;
				}
				
				
			},
			min: 0, 
			max: _model.retailing.maxNumberOfClients,
			step: _settings.simulatorSettings.retailing.numberOfClientsSliderStep
		});
		
		$('.retailing-sales-per-client-slider .slider').slider(
		{
			slide: function(evt, ui){
				
				if (!IE)
				{
					_model.retailing.salesPerClient = ui.value;
					_update('retailing');
				}
				
			},
			change: function(evt, ui){
				if(evt.originalEvent)
				{
					if (IE)
					{
						_model.retailing.salesPerClient = ui.value;
						_update('retailing');
					}
				
					$('.business-building-sales-per-client-slider .slider').slider({value: ui.value});
					_model.businessBuilding.salesPerClient = ui.value;
					_update('businessBuilding');
					_updateView('print');
					return;
				}
			},
			min: 0,
			max: _model.retailing.maxSalesPerClient,
			step: _settings.simulatorSettings.retailing.salesPerClientSliderStep
		});
		
		// Business Building
		$('.business-building-personal-orders-slider .slider').slider(
		{
			slide: function(evt, ui){
				if (!IE)
				{
					_model.businessBuilding.personalOrders = ui.value;
					_update('businessBuilding');
				}
				
			},
			change: function(evt, ui){
				if(evt.originalEvent)
				{
					if (IE)
					{
						_model.businessBuilding.personalOrders = ui.value;
						_update('businessBuilding');
					}
					
					$('.retailing-personal-orders-slider .slider').slider({value: ui.value});
					_model.retailing.personalOrders = ui.value;
					_update('retailing');
					_updateView('print');
					return;
				}
			},
			min: 0,
			max: _model.businessBuilding.maxPersonalOrders,
			step: _settings.simulatorSettings.businessBuilding.personalOrdersSliderStep
		});
		
		$('.business-building-number-of-clients-slider .slider').slider(
		{
			slide: function(evt, ui){
				if (!IE)
				{
					_model.businessBuilding.numberOfClients = ui.value;
					_update('businessBuilding');
				}
			},
			change: function(evt, ui){
				if(evt.originalEvent)
				{
					if (IE)
					{
						_model.businessBuilding.numberOfClients = ui.value;
						_update('businessBuilding');
					}
					
					$('.retailing-number-of-clients-slider .slider').slider({value: ui.value});
					_model.retailing.numberOfClients = ui.value;
					_update('retailing');
					_updateView('print');
					return;
				}
			},
			min: 0,
			max: _model.businessBuilding.maxNumberOfClients,
			step: _settings.simulatorSettings.businessBuilding.numberOfClientsSliderStep
		});
		
		$('.business-building-sales-per-client-slider .slider').slider(
		{
			slide: function(evt, ui){
				if (!IE)
				{
					_model.businessBuilding.salesPerClient = ui.value;
					_update('businessBuilding');
				}
			},
			change: function(evt, ui){
				if(evt.originalEvent){
					if (IE)
					{
						_model.businessBuilding.salesPerClient = ui.value;
						_update('businessBuilding');
					}
					
					$('.retailing-sales-per-client-slider .slider').slider({value: ui.value});
					_model.retailing.salesPerClient = ui.value;
					_update('retailing');
					_updateView('print');
					return;
				}
			},
			min: 0,
			max: _model.businessBuilding.maxSalesPerClient,
			step: _settings.simulatorSettings.businessBuilding.salesPerClientSliderStep
		});
		
		$('.leg-1-slider .vertical-slider').slider({
			orientation: 'vertical',
			slide: function(evt, ui){
				if (!IE)
				{
					_model.businessBuilding.legRetail[0] = ui.value;
					_update('businessBuilding');
				}
			},
			change: function(evt, ui){
				if (IE)
				{
					_model.businessBuilding.legRetail[0] = ui.value;
					_update('businessBuilding');
				}
				_updateView('print');
			},
			min: 0,
			max: _model.businessBuilding.maxRetailPerLeg,
			step: _settings.simulatorSettings.businessBuilding.legSliderStep
		});
		
		$('.leg-2-slider .vertical-slider').slider({
			slide: function(evt, ui){
				if (!IE)
				{
					_model.businessBuilding.legRetail[1] = ui.value;
					_update('businessBuilding');
				}
			},
			change: function(evt, ui){
				if (IE)
				{
					_model.businessBuilding.legRetail[1] = ui.value;
					_update('businessBuilding');
				}
				_updateView('print');
			},
			orientation: 'vertical',
			min: 0,
			max: _model.businessBuilding.maxRetailPerLeg,
			step: _settings.simulatorSettings.businessBuilding.legSliderStep
		});
		
		$('.leg-3-slider .vertical-slider').slider({
			orientation: 'vertical',
			slide: function(evt, ui){
				if (!IE)
				{
					_model.businessBuilding.legRetail[2] = ui.value;
					_update('businessBuilding');
				}
			},
			change: function(evt, ui){
				if (IE)
				{
					_model.businessBuilding.legRetail[2] = ui.value;
					_update('businessBuilding');
				}
				_updateView('print');
			},
			min: 0,
			max: _model.businessBuilding.maxRetailPerLeg,
			step: _settings.simulatorSettings.businessBuilding.legSliderStep
		});
		
		$('#my-goals-product-category select.select-category').change(function(){
			_setProductCategory($(this).val(), 'myGoals');
			
			
			$('#retailing-product-category select.select-category').selectBox("value",$(this).val());
			_setProductCategory($(this).val(), 'retailing');
			
		});
		
		$('#retailing-product-category select.select-category').change(function(){
			_setProductCategory($(this).val(), 'retailing');
			
			$('#my-goals-product-category select.select-category').selectBox("value",$(this).val());
			_setProductCategory($(this).val(), 'myGoals');
		});
		
		$('#simulator-tab-1').click(function(e){
			e.preventDefault();
			SWFAddress.setValue('simulator/my-goals');
		});
		
		$('#simulator-tab-2').click(function(e){
			e.preventDefault();
			SWFAddress.setValue('simulator/retailing');
			_model.retailing.maxMonthlyIncome = _getMaxRetailingMonthlyIncome();
		});
		
		$('#simulator-tab-3').click(function(e){
			e.preventDefault();
			SWFAddress.setValue('simulator/business-building');
			
		});
		
		$('.footer-block .home-button').click(function(e){
			e.preventDefault();
			SWFAddress.setValue('home');
		});
		
		// Default print button functionality
		$('.print-button').click(function(e){
			e.preventDefault();
			_updateView('print');
			window.print();
		});
		
		
		
		_update();
	};
	
	/**
	 * Update the simulator model with country specific options
	 * @param {Object} options
	 */
	var _initializeModelSettings = function(settings)
	{
		_model.myGoals.maxMonthlyIncome = settings.myGoals.maxMonthlyIncome;
		_model.myGoals.averageSalesPerClient = settings.myGoals.averageSalesPerClient;
		
		_model.retailing.maxPersonalOrders = settings.retailing.maxPersonalOrders;
		_model.retailing.maxNumberOfClients = settings.retailing.maxNumberOfClients;
		_model.retailing.maxSalesPerClient = settings.retailing.maxSalesPerClient;
		
		_model.businessBuilding.maxPersonalOrders = settings.businessBuilding.maxPersonalOrders;
		_model.businessBuilding.maxNumberOfClients = settings.businessBuilding.maxNumberOfClients;
		_model.businessBuilding.maxSalesPerClient = settings.businessBuilding.maxSalesPerClient;
		_model.businessBuilding.maxRetailPerLeg = settings.businessBuilding.maxRetailPerLeg;
		_model.businessBuilding.ratios = settings.businessBuilding.ratios;
		
		
		_model.bonuses.perfSchedules = settings.perfSchedules;
		_model.bonuses.ruby = settings.ruby;
		_model.bonuses.leadership = settings.leadership;
		
		_model.businessBuilding.maxMonthlyIncome = _getMaxBusinessBuildingMonthlyIncome();
	};
	
	var _initializeProductSettings = function(categories)
	{

		$('select.select-category').selectBox('destroy');
		$('select.select-category').html('');
		
		for(var i = 0; i < categories.length; i++)
		{
			var category = categories[i];

			var option = '<option value="'+ i +'">'+ category.name +'</option>';
			$('select.select-category').append(option);
			for(var j = 0; j < category.products.length; j++)
			{
				
				var product = category.products[j];
				product.markup = product.sr - product.dc;
			}		
		}
		
		$('select.select-category').selectBox('create');
		
		_setProductCategory(0, 'myGoals');
		
		_setProductCategory(0, 'retailing');
	};
	
	var _onLoad = function(data)
	{
		_settings = data;
		
		if(AMWAY.IncomeSimulator.Main.settings.local)
		{
			_settings = $.parseJSON(_settings);
		}
		
		_initializeModelSettings(_settings.simulatorSettings);
		_initializeProductSettings(_settings.productCategories);
	};
	
	return {
		onLoad: _onLoad,
		updateModel: _updateModel,
		updateView: _updateView,
		initUI: _initUI,
		showTabIndex: _showTabIndex,
		getMaxBusinessBuildingMonthlyIncome: _getMaxBusinessBuildingMonthlyIncome
	};
}());
